@@ -1,6 +1,5 @@
 import pyinspect as pi
 import sys
-import pytest
 import numpy as np
 
 
@@ -60,18 +59,5 @@ def test_traceback_args():
     raise_exception()
 
 
-def test_print_exception():
-    with pytest.raises(ZeroDivisionError):
-        # try:
-        1 / 0
-        # except Exception:
-        pi.print_exception()
-        pi.print_exception(message="Test")
-
-        exc_type, exc_value, traceback = sys.exc_info()
-        sys.excepthook(exc_type, exc_value, traceback)
-        pi.print_exception(traceback=traceback)
-
-
 def test_get_locals():
     pi._exceptions.get_locals()
