@@ -1,6 +1,10 @@
 import pyinspect as pi
 import pytest
 
+import numpy
+import matplotlib
+import pandas
+
 
 def test_timestamp():
     pi.utils.timestamp()
@@ -17,3 +21,8 @@ def test_readsingleline():
 def test_get_submodules():
     pi.utils.get_submodules(pi)
     pi.utils.get_submodules(pi.utils)
+
+    # tougher stuff
+    pi.utils.get_submodules(numpy)
+    pi.utils.get_submodules(matplotlib)
+    pi.utils.get_submodules(pandas)
